@@ -15,8 +15,9 @@ except ImportError:
 
 
 PACKAGE_NAME = 'tiddlywebplugins.tiddlyspace'
+TIDDLYWIKI_ALPHA = resource_filename(PACKAGE_NAME, 'resources/alpha.html')
 TIDDLYWIKI_BETA = resource_filename(PACKAGE_NAME, 'resources/beta.html')
-
+TIDDLYWIKI_EXTERNAL_ALPHA = resource_filename(PACKAGE_NAME, 'resources/external_alpha.html')
 
 config = {
     'instance_tiddlers': get_tiddler_locations(store_contents, PACKAGE_NAME),
@@ -33,8 +34,10 @@ config = {
     'indexer': 'tiddlywebplugins.mysql2',
     'tiddlywebwiki.binary_limit': 1048576,  # 1 MB
     'lazy.titles': ['SiteIcon', 'ColorPalette'],
-    # TiddlyWiki beta serialization
+    # TiddlyWiki external, alpha, beta serialization
     'base_tiddlywiki_beta': TIDDLYWIKI_BETA,
+    'base_tiddlywiki_alpha': TIDDLYWIKI_ALPHA,
+    'base_tiddlywiki_external_alpha': TIDDLYWIKI_EXTERNAL_ALPHA,
     'serializers': {
         'text/x-tiddlywiki': ['tiddlywebplugins.tiddlyspace.betaserialization',
             'text/html; charset=UTF-8']
